<?php

use EventPortal\AuthPassword\EmailAction;
use EventPortal\AuthPassword\Http\Controllers\HandleEmailAction;
use EventPortal\AuthPassword\Http\Middleware\CanCreatePassword;
use Illuminate\Support\Facades\App;

Route::middleware('web')
    ->namespace('EventPortal\AuthPassword\Http\Controllers')
    ->group(static function (): void {
        Route::get(EmailAction::HANDLER_ROUTE, [HandleEmailAction::class, '__invoke'])
            ->name(EmailAction::HANDLER_ROUTE);

        Route::get('login', 'LoginController@index')->name('login.index');
        Route::post('login', 'LoginController@login')->name('login.submit');
        Route::match(['get', 'post'], 'logout', 'LoginController@logout')->name('logout.submit');

        Route::get('reset-password', 'SendPasswordResetEmailController@showLinkRequestForm')
            ->name('reset-password.index');
        Route::post('reset-password', 'SendPasswordResetEmailController@sendResetLinkEmail')
            ->name('reset-password.submit');
        Route::get('password/reset', 'ResetPasswordController@showResetForm')->name('password.reset');
        Route::post('password/reset', 'ResetPasswordController@reset')->name('password.reset');

        Route::get('create-password/{token}', 'CreatePasswordController@index')
            ->name('create-password.index')
            ->middleware(CanCreatePassword::class);

        Route::post('create-password/{token}', 'CreatePasswordController@store')
            ->name('create-password.store')
            ->middleware(CanCreatePassword::class);
    });

if (App::environment('testing')) {
    Route::get('test-route')->name('test-route');
}
